<?php

Class lineChart
{
    //Зададим пути к требуемым файлам
    const FLASH_PATH="./FCF_MSLine.swf";
    const JAVASCRIPT_PATH="./FusionCharts.js";

    private $id;        //Идентификатор гафика на странице
    private $width;     //Ширина графика
    private $height;    //Высота графика
    private $caption;   //Заголовок
    private $category;  //Массив категорий (значения оси X)
    private $linesArray;//Массив линий

    
    /**
     *  Задаем начальные параметры графика
     *
     * @param string $id Идентификатор графика на странице
     * @param int $width Ширина
     * @param int $height Высота
     */
    public function __construct($id="myChart", $width=400, $height=300)
    {
        $this->id = $id;
        $this->width = $width;
        $this->height = $height;
    }


    /**
     * Добавление категорий
     *
     * @param array $data массив значений
     */
    public function setCategory($data)
    {
        $this->category = $data;
    }


    /**
     *  Добавление линии на график
     *
     * @param string $name Название линии
     * @param array $data Массив точек линии
     * @param string $color Цвет линии в формате RGB
     */
    public function addLine($name, $data, $color)
    {
        $this->linesArray[] = array(
            "name" => $name,
            "data" => $data,
            "color"=> $color
        );
    }

    /**
     * Установка заголовка графика
     *
     * @param string $caption
     */
    public function setCaption($caption)
    {
        $this->caption = $caption;
    }


    /**
     * Формирует данные для графика в XML формате
     *
     * @return sring данные в формате XML
     */
    private function buildXmlData()
    {
        $xml = "";

        //Формируем категории
        foreach($this->category as $category){
            $xml .= "<category name='$category'/>";
        }
        $xml = "<categories>$xml</categories>";

        //Формируем данные линий
        foreach($this->linesArray as $line){
            $lineXml = '';
            foreach($line['data'] as $dot){
                $lineXml .= "<set value='$dot'/>";
            }
            $xml .= "<dataset seriesName='{$line['name']}' "
                      ."color='{$line['color']}'>$lineXml</dataset>";
        }

        //Формируем конечный XML
        return "<graph caption='{$this->caption}'>$xml</graph>";
    }


    /**
     *  Возвращает HTML код, для добавления графика на страницу
     *
     * @return string
     */
    public function render()
    {
        return
        "<script language='JavaScript' src='".self::JAVASCRIPT_PATH."'></script>
        <div id='{$this->id}'> FusionCharts. </div>
        <script type='text/javascript'>
        var chart = new FusionCharts('".self::FLASH_PATH."',
         '{$this->id}', '{$this->width}', '{$this->height}');
        chart.setDataXML(\"".$this->buildXmlData()."\");
        chart.render('{$this->id}');
        </script>";
    }
}